-- RaidListExport
-- ver. 0.1.0
-- Author: Tifordin
-- http://www.wowace.com/projects/raid-list-export/

-- Useful links:
-- http://www.wowwiki.com/API_GetNumRaidMembers
-- http://www.wowwiki.com/API_GetRaidRosterInfo
-- http://www.wowwiki.com/API_EditBox_HighlightText

local output = ""

-------------------
-- Slash command --
-------------------

SLASH_RAIDLISTEXPORT1 = "/rle"
SLASH_RAIDLISTEXPORT2 = "/raidlistexport"

SlashCmdList["RAIDLISTEXPORT"] = function(msg, editbox)
	RaidListExport:Go()
end

---------
-- Ace --
---------

local L = LibStub("AceLocale-3.0"):GetLocale("RaidListExport", true)
RaidListExport = LibStub("AceAddon-3.0"):NewAddon("RaidListExport", "AceEvent-3.0")



--------------------
-- User Interface --
--------------------

local function CreateExportFrame()
	local f = CreateFrame("Frame", "RLEExportFrame", UIParent)
	f:Hide()
	f:SetPoint("CENTER")
	f:SetFrameStrata("TOOLTIP")
	f:SetHeight(350)
	f:SetWidth(500)
	f:SetBackdrop({
	          bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
	          edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
	          tile = true, tileSize = 32, edgeSize = 32,
	          insets = { left=11, right=12, top=12, bottom=11 },
	        })
	f:SetBackdropColor(0, 0, 0, 1)
	local help = f:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	help:SetPoint("TOP", f, "TOP", 0, -20)
	help:SetWidth(f:GetWidth() - 40)
	f.help = help
	
	local button1 = CreateFrame("Button", nil, f, "StaticPopupButtonTemplate")
	button1:SetPoint("BOTTOM", f, "BOTTOM", 0, 15)
	local button2 = CreateFrame("Button", nil, f, "StaticPopupButtonTemplate")
	button2:SetPoint("BOTTOM", button1, "BOTTOM")
	f.button1 = button1
	f.button2 = button2
	
	local s = CreateFrame("ScrollFrame", "RLEExportScrollFrame",
	                f, "UIPanelScrollFrameTemplate")
	s:SetPoint("TOPLEFT", help, "BOTTOMLEFT", 0, -10)
	s:SetPoint("TOPRIGHT", help, "BOTTOMRIGHT", -20, 0)
	s:SetPoint("BOTTOM", button1, "TOP", 0, 10)
	
	local b = CreateFrame("EditBox", nil, s)
	b:SetPoint("TOPLEFT")
	b:SetWidth(425)
	b:SetHeight(s:GetHeight())
	b:SetMultiLine(true)
	b:SetAutoFocus(false)
	b:SetFontObject(GameFontHighlight)
	b:SetScript("OnEscapePressed", function (self) self:ClearFocus() end)
	s:SetScrollChild(b)
	f.editbox = b
	
	f:SetScript(
		"OnShow",
		function (self)
			self.help:SetText("Copy the following text to paste into an external tool:")
			self.button1:Show()
			self.button1:SetText(CLOSE)
			self.button1:SetPoint("CENTER", self, "CENTER")
			self.button1:SetScript("OnClick", function (self) self:GetParent():Hide() end)
			self.button2:Hide()
			self.editbox:SetText(output)
			self.editbox:SetFocus()
			self.editbox:HighlightText()
		end
	)
	f:SetScript(
		"OnHide",
		function (self)
			self.editbox:SetText("")
		end
	)
	
	f:Show()
end


--------------------
-- Initialisation --
--------------------

function RaidListExport:OnInitialize()
end

function RaidListExport:OnEnable()
	-- Register the events we want to handle
end

function RaidListExport:OnDisable()
	self:UnregisterAllEvents()
end


function RaidListExport:Go()
	members = GetNumRaidMembers()
	if members == 0 then
		print("Raid List Export: Not in a raid.")
		return
	end
	
	output = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<raid>\n"
	
	players = {}
	
	for i=1,members do
		-- Get data
		name, rank, subgroup, level, class, fileName, zone, online, isDead, role, isML = GetRaidRosterInfo(i);
		
		-- Convert to the form we want it in
		players[i] = { name = name, rank = rank, subgroup = subgroup, level = level, class = class, fileName = fileName, zone = zone, online = online, isDead = isDead, role = role, isML = isML }
	end
	
	for i=1,8 do
		output = output .. " <group id=\"" .. i .. "\">\n"
		for k,v in pairs(players) do
			if v.subgroup == i then
				output = output .. "  <player>\n   <name>" .. v.name .. "</name>\n   <class>" .. v.class .. "</class>\n   <level>" .. v.level .. "</level>\n  </player>\n"
			end
		end
		output = output .. " </group>\n"
	end
	
	output = output .. "</raid>"
	
	CreateExportFrame()
end